# Security Policy

## Supported Versions

Which versions of your project are
currently being supported with security updates.

| Version | Supported          | ``semantic-release`` Version |
| ------- | ------------------ | -----------------------------|
| 1.24.x  | ☑️                 | 9.12                         |
| 1.25.x  | ☑️                 | 9.14                         |

## Disclosure

All known security vulnerabilities must be disclosed publically within 30 days of a detection during regular monitoring.

## Reporting a Vulnerability

A security vulnerability must never be posted in Issues.
This must be done directly through GitHub or via help@oziproject.dev

